##  Linking a Business Capability Fact Sheet from the Fact Sheet Page
Follow these steps:
  1. On the right-side pane of the business capability fact sheet, under Reference Catalog, click Start Linking. A page for linking the fact sheet to a catalog item opens.
  2. Under the search field on the left, select a suggested item to link or search for a specific item using the search field.
  3. Review the information on the right, then click Link. Here, you can also view suggested SAP solutions that support the business capability, if available.


![Linking a Reference Business Architecture Item to a Business Capability Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27449eca7a4410149a80dc4d6e3f5ab6_LowRes.png)
Linking a Business Capability Fact Sheet to a Catalog Item
